<?xml version="1.0" ?><!DOCTYPE TS><TS language="el" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source> About Boomaga</source>
        <translation> Σχετικά με το Boomaga</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Σχετικά</translation>
    </message>
    <message>
        <source>Authors</source>
        <translation>Συγγραφείς</translation>
    </message>
    <message>
        <source>Thanks</source>
        <translation>Ευχαριστίες</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Μεταφράσεις</translation>
    </message>
    <message>
        <source>Version: %1</source>
        <translation>Έκδοση: %1</translation>
    </message>
    <message>
        <source>Boomaga provides a virtual printer for CUPS. This can be used for print preview or for print booklets.</source>
        <translation>Το Boomaga παρέχει έναν εικονικό εκτυπωτή για το CUPS. Μπορεί να χρησιμοποιηθεί για την προεπισκόπηση εκτυπώσεων ή για την εκτύπωση βιβλιάριων.</translation>
    </message>
    <message>
        <source>Copyright: %1-%2 %3</source>
        <translation>Πνευματικά δικαιώματα: %1-%2 %3</translation>
    </message>
    <message>
        <source>Homepage: %1</source>
        <translation>Ιστοσελίδα: %1</translation>
    </message>
    <message>
        <source>License: %1</source>
        <translation>Άδεια χρήσης: %1</translation>
    </message>
    <message>
        <source>If you are interested in working with our development team, &lt;a %1&gt;join us&lt;/a&gt;.</source>
        <translation>Αν επιθυμείτε να λάβετε μέρος στην ομάδα μας, &lt;a %1&gt;ελάτε μαζί μας&lt;/a&gt;.</translation>
    </message>
    <message>
        <source>Special thanks to:</source>
        <translation>Ιδιαίτερες ευχαριστίες:</translation>
    </message>
    <message>
        <source>If you want to help translate, we will be glad to see you in our translation team on &lt;a %1&gt;Transifex server&lt;/a&gt;.</source>
        <translation>Αν επιθυμείτε να βοηθήσετε στη μετάφραση, με χαρά σας καλωσορίζουμε στην ομάδα μετάφρασης στην &lt;a %1&gt;πλατφόρμα Transifex&lt;/a&gt;.</translation>
    </message>
    <message>
        <source>Boomaga is developed by the &lt;a %1&gt;Boomaga Team and contributors&lt;/a&gt; on GitHub.</source>
        <translation>Το Boomaga αναπτύσσεται από την &lt;a %1&gt;ομάδα του Boomaga και τους συνεισφέροντες&lt;/a&gt; στο GitHub.</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Προτιμήσεις</translation>
    </message>
    <message>
        <source>Divide your long booklets into smaller sub-booklets for printing.</source>
        <translation>Διαιρεί τα μεγάλα βιβλιάρια σε μικρότερα υποβιβλιάρια για εκτύπωση.</translation>
    </message>
    <message>
        <source>Print as sub-booklets</source>
        <translation>Εκτύπωση ως υπο-βιβλιάρια</translation>
    </message>
    <message>
        <source>Maximum number of sheets in your sub-booklet.</source>
        <translation>Μέγιστος αριθμός φύλλων στα υπο-βιβλιάρια.</translation>
    </message>
    <message>
        <source>Sheets per sub-booklet:</source>
        <translation>Φύλλα ανά υπο-βιβλιάριο:</translation>
    </message>
    <message>
        <source>Autosave your jobs every time you print.</source>
        <translation>Αυτόματη αποθήκευση των εργασιών σε κάθε εκτύπωση.</translation>
    </message>
    <message>
        <source>AutoSave the recent sessions</source>
        <translation>Αυτόματη αποθήκευση των πρόσφατων συνεδριών</translation>
    </message>
    <message>
        <source>Allow negative page margins:</source>
        <translation>ΝΑ επιτρέπονται τα αρνητικά περιθώρια σελίδος:</translation>
    </message>
    <message>
        <source>Select directory for saved jobs.</source>
        <translation>Επιλογή καταλόγου των αποθηκευμένων εργασιών.</translation>
    </message>
    <message>
        <source>Directory for saved sessions:</source>
        <translation>Κατάλογος των αποθηκευμένων συνεδριών:</translation>
    </message>
</context>
<context>
    <name>ExportToPdf</name>
    <message>
        <source>Print to PDF</source>
        <translation>Εκτύπωση σε PDF</translation>
    </message>
    <message>
        <source>File name</source>
        <translation>Όνομα αρχείου</translation>
    </message>
    <message>
        <source>Output file:</source>
        <translation>Αρχείο εξόδου:</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Meta info</source>
        <translation>Μεταπληροφορίες</translation>
    </message>
    <message>
        <source>Author:</source>
        <translation>Συγγραφέας:</translation>
    </message>
    <message>
        <source> The name of the person who created the document.</source>
        <translation> Το όνομα του δημιουργού του εγγράφου.</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>Τίτλος:</translation>
    </message>
    <message>
        <source>Subject:</source>
        <translation>Θέμα:</translation>
    </message>
    <message>
        <source> The subject of the document.</source>
        <translation> Το θέμα του εγγράφου.</translation>
    </message>
    <message>
        <source> Keywords associated with the document.</source>
        <translation> Λέξεις κλειδιά συσχετισμένες με το έγγραφο.</translation>
    </message>
    <message>
        <source>Keywords:</source>
        <translation>Λέξεις κλειδιά:</translation>
    </message>
    <message>
        <source>PDF files (*.pdf);;All files (*.*)</source>
        <translation>Αρχεία PDF (*.pdf);;Όλα τα αρχεία (*.*)</translation>
    </message>
    <message>
        <source>Overwrite file?</source>
        <translation>Αντικατάσταση του αρχείου;</translation>
    </message>
    <message>
        <source>A file named &quot;%1&quot; already exists.
Are you sure you want to overwrite it?</source>
        <translation>Ένα αρχείο με όνομα %1 υπάρχει ήδη.
Επιθυμείτε σίγουρα την αντικατάστασή του;</translation>
    </message>
    <message>
        <source> The document&apos;s title.</source>
        <translation>  Ο τίτλος του εγγράφου.</translation>
    </message>
</context>
<context>
    <name>JobListView</name>
    <message>
        <source>%1 pages</source>
        <translation>%1 σελίδες</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Αρχεία</translation>
    </message>
    <message>
        <source>&amp;Preferences</source>
        <translation>&amp;Προτιμήσεις</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Βοήθεια</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>Διάταξη</translation>
    </message>
    <message>
        <source>1 up</source>
        <translation>1 σε 1</translation>
    </message>
    <message>
        <source>2 up</source>
        <translation>2 σε 1</translation>
    </message>
    <message>
        <source>Booklet</source>
        <translation>Βιβλιάριο</translation>
    </message>
    <message>
        <source>Print on both sides of a sheet.</source>
        <comment>MainForm::Double-sided checkbox tooltip</comment>
        <translation>Εκτύπωση στις δυο πλευρές του φύλλου.</translation>
    </message>
    <message>
        <source>Double-sided</source>
        <comment>MainForm::Double-sided checkbox</comment>
        <translation>Και στις δύο πλευρές</translation>
    </message>
    <message>
        <source>Jobs</source>
        <translation>Εργασίες</translation>
    </message>
    <message>
        <source>Printer</source>
        <translation>Εκτυπωτής</translation>
    </message>
    <message>
        <source>Configure...</source>
        <translation>Διαμόρφωση...</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Γραμμή εργαλείων</translation>
    </message>
    <message>
        <source>&amp;Print</source>
        <translation>Εκτύ&amp;πωση</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>Έ&amp;ξοδος</translation>
    </message>
    <message>
        <source>Print and Close</source>
        <translation>Εκτύπωση και κλείσιμο</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>Next sheet</source>
        <translation>Επόμενο φύλλο</translation>
    </message>
    <message>
        <source>Previous sheet</source>
        <translation>Προηγούμενο φύλλο</translation>
    </message>
    <message>
        <source>About Boomaga</source>
        <translation>Σχετικά με το Boomaga</translation>
    </message>
    <message>
        <source>Boomaga</source>
        <translation>Boomaga</translation>
    </message>
    <message>
        <source>%v of %m</source>
        <comment>Format for QProgressBar (http://qt-project.org/doc/qt-4.8/qprogressbar.html#format-prop)</comment>
        <translation>%v από %m</translation>
    </message>
    <message>
        <source>Print the all pages on %1.</source>
        <translation>Εκτύπωση όλων των σελίδων στον %1.</translation>
    </message>
    <message>
        <source>Print the odd pages on %1.&lt;p&gt;When finished, turn the pages, insert them into the printer&lt;br&gt;and click the Continue button.</source>
        <translation>Εκτύπωση των μονών σελίδων στον %1.&lt;p&gt;Μετά το πέρας, γυρίστε τις σελίδες, εισχωρήστε τες στον εκτυπωτή&lt;br&gt;και κάντε κλικ στο κουμπί Συνέχεια.</translation>
    </message>
    <message>
        <source>Print the even pages on %1.</source>
        <translation>Εκτύπωση των ζυγών σελίδων στον %1.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Συνέχεια</translation>
    </message>
    <message>
        <source>%1 pages</source>
        <comment>Status bar</comment>
        <translation>%1 σελίδες</translation>
    </message>
    <message>
        <source>%1 page</source>
        <comment>Status bar</comment>
        <translation>%1 σελίδα</translation>
    </message>
    <message>
        <source>%1 sheets</source>
        <comment>Status bar</comment>
        <translation>%1 φύλλα</translation>
    </message>
    <message>
        <source>%1 sheet</source>
        <comment>Status bar</comment>
        <translation>%1 φύλλο</translation>
    </message>
    <message>
        <source>Sheet %1 of %2</source>
        <comment>Status bar</comment>
        <translation>Φύλλο %1 από %2</translation>
    </message>
    <message>
        <source>Insert blank page after this page</source>
        <translation>Εισαγάγετε μια λευκή σελίδα μετά από αυτή</translation>
    </message>
    <message>
        <source>Delete this page</source>
        <translation>Διαγράψτε αυτήν τη σελίδα</translation>
    </message>
    <message>
        <source>Undo delete</source>
        <translation>Επαναφορά της διαγραφής</translation>
    </message>
    <message>
        <source>Insert blank page before this page</source>
        <translation>Εισαγάγετε μια λευκή σελίδα πριν από αυτή</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Αποθήκευση</translation>
    </message>
    <message>
        <source>Save project</source>
        <translation>Αποθήκευση του έργου</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Save as...</source>
        <translation>Αποθήκευση ως...</translation>
    </message>
    <message>
        <source>Save project under a new name</source>
        <translation>Αποθήκευση του έργο υπό ενός νέου ονόματος</translation>
    </message>
    <message>
        <source>Ctrl+Shift+S</source>
        <translation>Ctrl+Shift+S</translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>Άνοιγμα...</translation>
    </message>
    <message>
        <source>Open an existing project</source>
        <translation>Άνοιγμα ενός υπάρχοντος έργου</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Page %1</source>
        <comment>'Undo deletion' menu item</comment>
        <translation>Σελίδα %1</translation>
    </message>
    <message>
        <source>Boomaga files (*.boo);;All files (*.*)</source>
        <translation>Αρχεία Boomaga  (*.boo)··Όλα τα αρχεία (*.*)</translation>
    </message>
    <message>
        <source>Project saved successfully.</source>
        <translation>Το έργο αποθηκεύτηκε επιτυχώς.</translation>
    </message>
    <message>
        <source>All supported files (*.pdf *.boo);;Boomaga files (*.boo);;PDF files (*.pdf);;All files (*.*)</source>
        <translation>Όλα τα υποστηριζόμενα αρχεία (*.pdf *.boo)··Αρχεία Boomaga (*.boo)··Αρχεία PDF (*.pdf)··΄Όλα τα αρχεία (*.*)</translation>
    </message>
    <message>
        <source>4 up horizontal</source>
        <translation>Τετράδα οριζόντια</translation>
    </message>
    <message>
        <source>4 up vertical</source>
        <translation>Τετράδα κατακόρυφα</translation>
    </message>
    <message>
        <source>8 up horizontal</source>
        <translation>Οκτάδα οριζόντια</translation>
    </message>
    <message>
        <source>8 up vertical</source>
        <translation>Οκτάδα κατακόρυφα</translation>
    </message>
    <message>
        <source>Start new booklet from this page</source>
        <translation>Δημιουργία ενός νέου βιβλιαρίου από από αυτήν τη σελίδα</translation>
    </message>
    <message>
        <source>Don&apos;t start new booklet from this page</source>
        <translation>Να μην γίνει δημιουργία ενός νέου βιβλιαρίου από αυτήν την σελίδα</translation>
    </message>
    <message>
        <source>Rotate page to the left</source>
        <translation>Περιστροφή της σελίδας αριστερά</translation>
    </message>
    <message>
        <source>Rotate page to the right</source>
        <translation>Περιστροφή της σελίδας δεξιά</translation>
    </message>
    <message>
        <source>Rename job</source>
        <translation>Μετονομασία της εργασίας</translation>
    </message>
    <message>
        <source>Rotate job to the left</source>
        <translation>Περιστροφή της εργασίας αριστερά</translation>
    </message>
    <message>
        <source>Rotate job to the right</source>
        <translation>Περιστροφή της εργασίας δεξιά</translation>
    </message>
    <message>
        <source>Job title:</source>
        <translation>Τίτλος εργασίας:</translation>
    </message>
    <message>
        <source>Export the project to PDF</source>
        <translation>Εξαγωγή του έργου ως PDF</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Clone job...</source>
        <translation>Κλωνοποίηση της εργασίας...</translation>
    </message>
    <message>
        <source>Clone job</source>
        <translation>Κλωνοποίηση της εργασίας</translation>
    </message>
    <message>
        <source>Number of copies:</source>
        <translation>Αριθμός αντιγράφων:</translation>
    </message>
    <message>
        <source>Print with options...</source>
        <translation>Εκτύπωση με επιλογές...</translation>
    </message>
    <message>
        <source>Select number of copies before printing.</source>
        <translation>Επιλκέξτε τον αριθμό των αντιγράφων πριν την εκτύπωση.</translation>
    </message>
    <message>
        <source>Ctrl+Shift+P</source>
        <translation>Ctrl+Shift+P</translation>
    </message>
    <message>
        <source>Sub-booklets</source>
        <translation>Υπο-βιβλιάρια</translation>
    </message>
    <message>
        <source>Undo delete page</source>
        <translation>Αναίρεση της διαγραφής της σελίδας</translation>
    </message>
    <message>
        <source>Page %1 of %2</source>
        <comment>Status bar</comment>
        <translation>Σελίδα %1 από %2</translation>
    </message>
    <message>
        <source>Recent files</source>
        <translation>Πρόσφατα αρχεία</translation>
    </message>
    <message>
        <source>&amp;Edit page</source>
        <translation>&amp;Επεξεργασία σελίδας</translation>
    </message>
    <message>
        <source>Edit &amp;job</source>
        <translation>Επεξεργασία ε&amp;ργασίας</translation>
    </message>
    <message>
        <source>&amp;Export to PDF...</source>
        <translation>Εξαγωγή σε &amp;PDF...</translation>
    </message>
    <message>
        <source>Delete pages until the end of the job</source>
        <translation>Διαγράψτε τις υπολειπόμενες σελίδες της εργασίας εκτύπωσης</translation>
    </message>
    <message>
        <source>Delete current job</source>
        <translation>Διαγραφή της τρέχουσας εργασίας</translation>
    </message>
    <message>
        <source>Auto saving</source>
        <translation>Αυτόματη αποθήκευση</translation>
    </message>
    <message>
        <source>I can&apos;t create directory &quot;%1&quot;</source>
        <translation>Αδύνατη η δημιουργία του καταλόγου «%1»</translation>
    </message>
    <message>
        <source>%1 %2: Page %3</source>
        <comment>'Undo deletion' menu item, (%1 - is a job number, %2 - is a job title, %3 - is a page number in this job</comment>
        <translation>%1 %2: Σελίδα %3</translation>
    </message>
</context>
<context>
    <name>PdfMerger</name>
    <message>
        <source>I can&apos;t write file &quot;%1&quot;</source>
        <translation>Αδύνατη η εγγραφή του αρχείου «%1»</translation>
    </message>
</context>
<context>
    <name>PrintDialog</name>
    <message>
        <source>Print document</source>
        <translation>Εκτύπωση του εγγράφου</translation>
    </message>
    <message>
        <source>Number of copies:</source>
        <translation>Αριθμός αντιγράφων:</translation>
    </message>
    <message>
        <source>Collate copies:</source>
        <translation>Τοποθέτηση σε σειρά των αντιγράφων:</translation>
    </message>
</context>
<context>
    <name>PrinterSettings</name>
    <message>
        <source>Margins (mm)</source>
        <translation>Περιθώρια (mm)</translation>
    </message>
    <message>
        <source>Right:</source>
        <translation>Δεξιά:</translation>
    </message>
    <message>
        <source>Bottom:</source>
        <translation>Κάτω:</translation>
    </message>
    <message>
        <source>Internal:</source>
        <translation>Εσωτερικό:</translation>
    </message>
    <message>
        <source>Left:</source>
        <translation>Αριστερά:</translation>
    </message>
    <message>
        <source>Top:</source>
        <translation>Πάνω:</translation>
    </message>
    <message>
        <source>Draw border</source>
        <translation>Σχεδίαση περιγράμματος</translation>
    </message>
    <message>
        <source>Print in reverse order</source>
        <translation>Εκτύπωση σε αντίστροφη σειρά</translation>
    </message>
    <message>
        <source>Printer has duplexer</source>
        <translation>Εκτυπωτής διπλής όψης</translation>
    </message>
    <message>
        <source>Manual with reverse (suitable for most printers)</source>
        <translation>Χειροκίνητος με αναστροφή (κατάλληλος στην πλειοψηφία των εκτυπωτών)</translation>
    </message>
    <message>
        <source>Manual without reverse</source>
        <translation>Χειροκίνητος χωρίς αναστροφή</translation>
    </message>
    <message>
        <source>Preferences of &quot;%1&quot;</source>
        <translation>Προτιμήσεις του «%1»</translation>
    </message>
    <message>
        <source>Profiles</source>
        <translation>Ταυτότητες</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Reset to default</source>
        <translation>Επαναφορά στο προκαθορισμένο</translation>
    </message>
    <message>
        <source>Profile %1</source>
        <comment>Defaul name for created printer profile in the Printer Settings diaog</comment>
        <translation>Ταυτότητα %1</translation>
    </message>
    <message>
        <source>Color mode:</source>
        <translation>Λειτουργία χρώματος:</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Εξ ορισμού</translation>
    </message>
    <message>
        <source>Force grayscale</source>
        <translation>Εξαναγκασμός ασπρόμαυρου χρωματισμού</translation>
    </message>
    <message>
        <source>Force color</source>
        <translation>Εξαναγκασμός χρώματος</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ρυθμίσεις</translation>
    </message>
    <message>
        <source>Print on both sides</source>
        <translation>Εκτύπωση στις δυο πλευρές</translation>
    </message>
    <message>
        <source>Flip on short edge</source>
        <translation>Αλλαγή πλευράς σε κοντή άκρη</translation>
    </message>
    <message>
        <source>Flip on long edge</source>
        <translation>Αλλαγή πλευράς σε μακριά άκρη</translation>
    </message>
</context>
<context>
    <name>Project</name>
    <message>
        <source>Boomaga</source>
        <comment>Error message title</comment>
        <translation>Boomaga</translation>
    </message>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation>Αδύνατη η εγγραφή στο αρχείο «%1»</translation>
    </message>
    <message>
        <source>I can&apos;t open file &quot;%1&quot; (No such file or directory)</source>
        <translation>Δεν μπορώ να ανοίξω το αρχείο «%1» (Δεν υπάρχει τέτοιο αρχείο ή κατάλογος)</translation>
    </message>
    <message>
        <source>I can&apos;t open file &quot;%1&quot; (Access denied)</source>
        <translation>Δεν μπορώ να ανοίξω το αρχείο «%1» (Άρνηση πρόσβασης)</translation>
    </message>
    <message>
        <source>I can&apos;t open file &quot;%1&quot;</source>
        <translation>Αδύνατο το άνοιγμα του αρχείου «%1»</translation>
    </message>
    <message>
        <source>I can&apos;t read file &quot;%1&quot; either because it&apos;s not a supported file type, or because the file has been damaged.</source>
        <translation>Δεν μπορώ να αναγνώσω του αρχείο «%1» είτε λόγω ενός μη υποστηριζόμενου τύπου αρχείου, είτε λόγω ενός κατεστραμμένου αρχείου.</translation>
    </message>
</context>
<context>
    <name>ProjectFile</name>
    <message>
        <source>I can&apos;t open file &quot;%1&quot;</source>
        <translation>Αδύνατο το άνοιγμα του αρχείου «%1»</translation>
    </message>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation>Αδύνατη η εγγραφή στο αρχείο «%1»</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>I can&apos;t read from file &apos;%1&apos;</source>
        <translation>Δεν μπορώ να αναγνώσω από το αρχείο «%1»</translation>
    </message>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation>Αδύνατη η εγγραφή στο αρχείο «%1»</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Άτιτλο</translation>
    </message>
    <message>
        <source>Default</source>
        <comment>Printer profile default name</comment>
        <translation>Εξ ορισμού</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>~/Untitled.pdf</source>
        <translation>~/Άτιτλο.pdf</translation>
    </message>
</context>
<context>
    <name>SubBookletView</name>
    <message>
        <source>Sub-booklet %1</source>
        <translation>Υπο-βιβλιάριο %1</translation>
    </message>
    <message>
        <source>%1 pages</source>
        <translation>%1 σελίδες</translation>
    </message>
</context>
<context>
    <name>TmpPdfFile</name>
    <message>
        <source>I can&apos;t create temporary file &quot;%1&quot;</source>
        <translation>Αδύνατη η δημιουργία του προσωρινού αρχείου «%1»</translation>
    </message>
    <message>
        <source>Something is wrong. I can't find boomagamerger program.
Please reinstall me.</source>
        <translation>Κάτι έχει πάει στραβά. Δεν μπορώ να βρω το πρόγραμμα boomagamerger.
Παρακαλώ επανεγκαταστήστε με.</translation>
    </message>
    <message>
        <source>I can&apos;t read file &apos;%1&apos;</source>
        <translation>Αδύνατη η ανάγνωση του αρχείου «%1»</translation>
    </message>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation>Αδύνατη η εγγραφή στο αρχείο «%1»</translation>
    </message>
</context>
</TS>